Authors:

* Peter Amstutz, Curii Inc. / Arvados; https://orcid.org/0000-0003-3566-7705
* Michael R. Crusoe, CWL Project Lead; https://orcid.org/0000-0002-2961-9670
* Kaushik Ghose, Seven Bridges Genomics, Inc; https://orcid.org/0000-0003-2933-1260
* Stian Soiland-Reyes, University of Manchester; https://orcid.org/0000-0001-9842-9718

Contributors: TBD 

This specification is a draft, and has not yet been approved as an official CWL standard.

<!-- v1.2.0-devN is not yet approvied
This specification was [approved on 6 June 2019](https://github.com/common-workflow-language/common-workflow-language/issues/861) by the CWL leadership team consisting of:

* Peter Amstutz, Curii Inc. / Arvados; https://orcid.org/0000-0003-3566-7705
* John Chilton, Pennsylvania State University / Galaxy Project; https://orcid.org/0000-0002-6794-0756
* Michael R. Crusoe, CWL Project Lead; https://orcid.org/0000-0002-2961-9670
* Brandi Davis Dusenbery, Seven Bridges Genomics, Inc.; https://orcid.org/0000-0001-7811-8613
* Jeff Gentry, Broad Institute; https://orcid.org/0000-0001-5351-8442
* Hervé Ménager, Institut Pasteur; https://orcid.org/0000-0002-7552-1009
* Stian Soiland-Reyes, University of Manchester; https://orcid.org/0000-0001-9842-9718

-->
